import net.mawis.imip.*;
import java.io.*;

public class IMIPClient implements StateChangeListener, IMMessageListener, RosterChangeListener {
	static ServerConnection sc;

	public static void printHelp() {
		System.out.println("Commands:");
		System.out.println("help                   ... print commands");
		System.out.println("msg <userid> <message> ... send a message to an user");
		System.out.println("stat <status>          ... set presence to ONLINE, OFFLINE, AWAY or BUSY");
	}
	
	public static void main(String[] args) {
		if (args.length != 2) {
			System.out.println("needed arguments: <user> <password>");
			System.exit(0);
		}
		sc = new ServerConnection("imip.odigo.com", 11319, args[0], args[1]);

		IMIPClient clientInstance = new IMIPClient();
		sc.addStateChangeListener(clientInstance);
		sc.addIMMessageListener(clientInstance);
		sc.getRoster().addRosterChangeListener(clientInstance);
		try {
			sc.connect();
		} catch (IOException ioe) {
			System.out.println("Caught IOException while connecting");
		}

		BufferedReader in = new BufferedReader(new InputStreamReader(System.in));

		printHelp();
		String commandLine="";
		String command = "";
		String commandParam = "";
		try {
			commandLine = in.readLine().trim();
		} catch (Exception e) {}
		int pos = commandLine.indexOf(' ');
		if (pos >= 0) {
			command = commandLine.substring(0, pos);
			commandParam = commandLine.substring(pos+1).trim();
		} else {
			command = commandLine;
			commandParam = "";
		}

		while (!command.equals("quit")) {
			if (command.equals("help")) {
				printHelp();
			} else if (command.equals("stat")) {
				sc.sendPacketWithID(IMPresence.getNewIMPresence(new PresenceState(commandParam.toUpperCase()), "UTF-8"));
			} else if (command.equals("msg")) {
				pos = commandParam.indexOf(' ');
				if (pos < 0) {
					System.out.println("msg <id> <message>");
				} else {
					String id = commandParam.substring(0, pos);
					String msg = commandParam.substring(pos+1);

					IMMessage mpkt = IMMessage.getNewIMMessage(id, args[0], "UTF-8");
					mpkt.setBody(msg);
					sc.sendPacketWithID(mpkt);
				}
			} else {
				System.out.println("Unknown command ... help of list of valid commands");
			}
			
			try {
				commandLine = in.readLine().trim();
			} catch (Exception e) {
				commandLine = "";
			}
			pos = commandLine.indexOf(' ');
			if (pos >= 0) {
				command = commandLine.substring(0, pos);
				commandParam = commandLine.substring(pos+1).trim();
			} else {
				command = commandLine;
				commandParam = "";
			}
		}

		sc.disconnect();
	}

	public void newConnectionState(ConnectionState newState) {
		System.out.println(newState.toString());

		if (newState.getState() == ConnectionState.STATE_CONNECTED) {
			IMPacket imp = IMPacket.getNewIMPacket("STAT ONLINE", "UTF-8");

			sc.sendPacketWithID(imp);
		}
	}

	public void newMessageReceived(IMMessage newMessage) {
		System.out.println("New message received from "+newMessage.getFrom());
		System.out.println("Time: "+newMessage.getDate());
		System.out.println("Body: "+newMessage.getBody());
	}

	public void rosterItemChanged(RosterItem changedItem, boolean more) {
		System.out.println(changedItem.toString());
	}
}
