package net.mawis.imip;

/**
 * This represents the state of a connection
 *
 * @author Matthias Wimmer &lt;m@tthias.net&gt;
 * @version 0.1.0
 */
public class ConnectionState {
    private int state;

    public final static int STATE_DISCONNECTED = 0;
    public final static int STATE_CONNECTING = 1;
    public final static int STATE_AUTHENTICATING = 2;
    public final static int STATE_CONNECTED = 3;
    public final static int STATE_ERROR = 4;

    /**
     * Instantiate a new ConnectionState
     */
    public ConnectionState() {
	state = STATE_DISCONNECTED;
    }

    /**
     * get the connection state
     *
     * @return the connection state
     */
    public int getState() {
	return state;
    }

    /**
     * update the connection state
     *
     * @param newState the new state of the connection
     */
    public void setState(int newState) {
	state = newState;
    }

    /**
     * get the connection state as a String
     *
     * @return connection state
     */
    public String toString() {
	switch (state) {
	    case STATE_DISCONNECTED:
		return "disconnected";
	    case STATE_CONNECTING:
		return "connecting";
	    case STATE_AUTHENTICATING:
		return "authenticating";
	    case STATE_CONNECTED:
		return "connected";
	    case STATE_ERROR:
		return "error";
	    default:
		return "unknown state";
	}
    }
}
