package net.mawis.imip;

import java.io.*;
/**
 * This is an IMPacket that represents presence information
 *
 * @author Matthias Wimmer &lt;m@tthias.net&gt;
 * @version 0.1.0
 */
public class IMPresence extends IMPacket {
    /**
     * Construct a new IMPresence
     *
     * @param type of the packet
     * @param encoding encoding of the packet
     */
    protected IMPresence(String type, String encoding) {
	super(type, encoding);
    }

    /**
     * Read an IMPresence from an InputStream
     *
     * @param stream the InputStream to read from
     * @param type the type of the packet
     * @param encoding encoding of the packet
     */
    protected IMPresence(InputStream stream, String type, String encoding) throws IOException {
	super(stream, type, encoding);
    }

    /**
     * Get the PresenceState of this packet
     *
     * @return the presence state
     */
    public PresenceState getPresenceState() {
	return new PresenceState(getSubType());
    }

    /**
     * get a new IMPresence packet
     *
     * @param presence the presence state
     * @param encoding the encoding of the packet
     * @return the IMPresence packet
     */
    public static IMPresence getNewIMPresence(PresenceState presence, String encoding) {
	return new IMPresence("STAT "+presence.toString().toUpperCase(), encoding);
    }

    /**
     * get the sender of the presence
     *
     * @return the sender's ID
     */
    public String getSenderID() {
	String id = getHeader("From");
	return getMainTypeFromString(id);
    }
}
