package net.mawis.imip;

import java.io.*;
import java.util.*;

/**
 * This is an IMPacket that represents an authorization request or reply
 *
 * @author Matthias Wimmer &lt;m@tthias.net&gt;
 * @version 0.1.0
 */
public class IMSubscription extends IMPacket {
    /**
     * Construct a new IMSubscription
     *
     * @param type type of the packet
     * @param encoding encoding of the packet
     */
    protected IMSubscription(String type, String encoding) {
	super(type, encoding);
    }

    /**
     * Read an IMSubscription from an InputStream
     *
     * @param stream the InputStream to read from
     * @param type the type of the packet
     * @param encoding encoding of the packet
     */
    protected IMSubscription(InputStream stream, String type, String encoding) throws IOException {
	super(stream, type, encoding);
    }

    /**
     * Generate subscription request reply
     *
     * @param ourID our user id
     * @param accept true if we accept the request
     * @return the reply packet
     */
    public IMSubscription getReply(String userID, boolean accept) {
	if (getHeader("From") == null) {
	    return null;
	}

	String packetType = accept ? "LIST ACCEPT " : "LIST REJECT ";

	IMSubscription replyPacket = (IMSubscription)getNewIMPacket(packetType+getHeader("From"), encoding);
	replyPacket.addHeader("From", userID);
	return replyPacket;
    }

    /**
     * Generate a subscription request
     *
     * @param userID the user we want to subscribe to
     * @param ourID our user id
     * @param add true to add an user, false to remove an user
     * @return the subscription packet
     */
    public IMSubscription getSubscriptionRequest(String userID, String ourID, boolean add) {
	String pktHeader = add ? "LIST ADD " : "LIST REMOVE ";
	pktHeader += userID;

	IMSubscription subscriptionPacket = (IMSubscription)getNewIMPacket(pktHeader, encoding);
	subscriptionPacket.addHeader("List", "Buddy");
	subscriptionPacket.addHeader("From", ourID);
	return subscriptionPacket;
    }
}
