package net.mawis.imip;

/**
 * This represents a presence of an IM user
 *
 * @author Matthias Wimmer &lt;m@tthias.net&gt;
 * @version 0.1.0
 */
public class PresenceState {
    public static final int PRESENCE_OFFLINE = 0;
    public static final int PRESENCE_ONLINE = 1;
    public static final int PRESENCE_AWAY = 2;
    public static final int PRESENCE_BUSY = 3;

    private int presence;

    /**
     * Instantiate a new PresenceState
     */
    public PresenceState() {
	presence = PRESENCE_OFFLINE;
    }

    /**
     * Instantiate a new PresenceState
     *
     * @param presence the initial state
     */
    public PresenceState(String presence) {
	setPresence(presence);
    }

    /**
     * get the presence
     *
     * @return the presence
     */
    public int getPresence() {
	return presence;
    }

    /**
     * change the presence
     *
     * @param newPresence the new presence
     */
    public void setPresence(int newPresence) {
	presence = newPresence;
    }

    /**
     * change the presence
     *
     * @param newPresence the new presence
     */
    public void setPresence(String newPresence) {
	if (newPresence.equals("ONLINE")) {
	    presence = PRESENCE_ONLINE;
	} else if (newPresence.equals("OFFLINE")) {
	    presence = PRESENCE_OFFLINE;
	} else if (newPresence.equals("AWAY")) {
	    presence = PRESENCE_AWAY;
	} else if (newPresence.equals("BUSY")) {
	    presence = PRESENCE_BUSY;
	} else {
	    presence = PRESENCE_OFFLINE;
	}
    }

    /**
     * get String representation of the presence
     *
     * @return presence as a string
     */
    public String toString() {
	switch (presence) {
	    case PRESENCE_OFFLINE:
		return "offline";
	    case PRESENCE_ONLINE:
		return "online";
	    case PRESENCE_AWAY:
		return "away";
	    case PRESENCE_BUSY:
		return "busy";
	    default:
		return "unknown presence";
	}
    }

    /**
     * check if two PresenceState instances represent the same state
     *
     * @param state the state to compare with
     * @return true if they are the same
     */
    public boolean equals(PresenceState state) {
	return (presence == state.presence);
    }
}
